package cn.iocoder.yudao.module.shipment.controller.admin;

import cn.iocoder.yudao.framework.idempotent.core.annotation.Idempotent;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.shipment.convert.BoxAirShipmentConvert;
import cn.iocoder.yudao.module.shipment.dal.dataobject.BoxAirShipmentDO;
import cn.iocoder.yudao.module.shipment.service.boxAirShipment.BoxAirShipmentService;
import cn.iocoder.yudao.module.shipment.vo.boxAirShipment.*;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

@Validated
@RestController
@Api(tags = "管理后台 - 空运出货")
@RequestMapping("/ecw/box-air-shipment")
public class BoxAirShipmentController {

    @Resource
    private BoxAirShipmentService boxAirShipmentService;

    @PostMapping("/create")
    @ApiOperation("创建空运出货")
    @Idempotent(timeout = 5)
    //@PreAuthorize("@ss.hasPermission('ecw:box-air-shipment:create')")
    public CommonResult<Long> createBoxAirShipment(@Valid @RequestBody BoxAirShipmentCreateReqVO createReqVO) {
        return success(boxAirShipmentService.createBoxAirShipment(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新空运出货")
    @Idempotent(timeout = 5)
    //@PreAuthorize("@ss.hasPermission('ecw:box-air-shipment:update')")
    public CommonResult<Boolean> updateBoxAirShipment(@Valid @RequestBody BoxAirShipmentUpdateReqVO updateReqVO) {
        boxAirShipmentService.updateBoxAirShipment(updateReqVO);
        return success(true);
    }

    @PutMapping("/recall")
    @ApiOperation("撤回空运出货")
    @Idempotent(timeout = 5)
    //@PreAuthorize("@ss.hasPermission('ecw:box-air-shipment:update')")
    public CommonResult<Boolean> recallBoxAirShipment(@Valid @RequestBody BoxAirShipmentUpdateReqVO updateReqVO) {
        boxAirShipmentService.recallBoxAirShipment(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除空运出货")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    //@PreAuthorize("@ss.hasPermission('ecw:box-air-shipment:delete')")
    public CommonResult<Boolean> deleteBoxAirShipment(@RequestParam("id") Long id) {
        boxAirShipmentService.deleteBoxAirShipment(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得空运出货")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    //@PreAuthorize("@ss.hasPermission('ecw:box-air-shipment:query')")
    public CommonResult<BoxAirShipmentBackVO> getBoxAirShipment(@RequestParam("id") Long id) {
        BoxAirShipmentDO boxAirShipment = boxAirShipmentService.getBoxAirShipment(id);
        return success(BoxAirShipmentConvert.INSTANCE.convert(boxAirShipment));
    }

    @GetMapping("/list")
    @ApiOperation("获得空运出货列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    //@PreAuthorize("@ss.hasPermission('ecw:box-air-shipment:query')")
    public CommonResult<List<BoxAirShipmentBackVO>> getBoxAirShipmentList(@RequestParam("ids") Collection<Long> ids) {
        List<BoxAirShipmentDO> list = boxAirShipmentService.getBoxAirShipmentList(ids);
        return success(BoxAirShipmentConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得空运出货分页")
    //@PreAuthorize("@ss.hasPermission('ecw:box-air-shipment:query')")
    public CommonResult<PageResult<BoxAirShipmentBackVO>> getBoxAirShipmentPage(@Valid BoxAirShipmentQueryVO query, PageVO page) {
        PageResult<BoxAirShipmentDO> pageResult = boxAirShipmentService.getBoxAirShipmentPage(query, page);
        return success(BoxAirShipmentConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出空运出货 Excel")
    //@PreAuthorize("@ss.hasPermission('ecw:box-air-shipment:export')")
    @OperateLog(type = EXPORT)
    public void exportBoxAirShipmentExcel(@Valid BoxAirShipmentQueryVO query,
              HttpServletResponse response) throws IOException {
        List<BoxAirShipmentDO> list = boxAirShipmentService.getBoxAirShipmentList(query);
        // 导出 Excel
        List<BoxAirShipmentBackVO> datas = BoxAirShipmentConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "空运出货.xls", "数据", BoxAirShipmentBackVO.class, datas);
    }

    @GetMapping("/getAirShipmentByShipmentId")
    @ApiOperation("根据出货id获得空运出货")
    @ApiImplicitParam(name = "shipmentId", value = "出货编号", required = true, example = "1024", dataTypeClass = Long.class)
    //@PreAuthorize("@ss.hasPermission('ecw:box-air-shipment:query')")
    public CommonResult<BoxAirShipmentBackVO> getAirShipmentByShipmentId(@RequestParam("shipmentId") Long shipmentId) {
        BoxAirShipmentDO boxAirShipment = boxAirShipmentService.getAirShipmentByShipmentId(shipmentId);
        return success(BoxAirShipmentConvert.INSTANCE.convert(boxAirShipment));
    }
}
